.. django-public-project documentation master file, created by
   sphinx-quickstart on Mon Aug  6 14:08:32 2012.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

django-public-project - Documentation
=====================================

**Django Public Project (DPP)** is an open source software 
(`GitHub <https://github.com/holgerd77/django-public-project>`_)
for **creating/maintaining an information website 
around a public project** (building of a new opera house or an airport, long-term preparations for a big sports event,...)
bringing transparency to the roles of stakeholders, important events as well as the overall project progress.

DPP was initially funded by the pirate party in the german parliaments of Berlin and 
North Rhine-Westphalia for their projects 
`BERwatch (german) <https://ber.piratenfraktion-berlin.de/>`_ and 
`BLBwatch (german) <https://blb.piratenfraktion-nrw.de/>`_.

Manual
------

.. toctree::
   :maxdepth: 2
   
   getting_started
   tutorial
   administration
   developers


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

